
* Webpage: https://gammapy.org
* Documentation: https://docs.gammapy.org
* Code: https://github.com/gammapy/gammapy

Gammapy is an open-source Python package for gamma-ray astronomy built on Numpy and Astropy.
It is a prototype for the Cherenkov Telescope Array (CTA) science tools,
and can also be used to analyse data from existing gamma-ray telescopes.
